'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function appendNode ( node, target ) {
	target.appendChild( node );
}

function insertNode ( node, target, anchor ) {
	target.insertBefore( node, anchor );
}

function detachNode ( node ) {
	node.parentNode.removeChild( node );
}

function createElement ( name ) {
	return document.createElement( name );
}

function createComment () {
	return document.createComment( '' );
}

function addEventListener ( node, event, handler ) {
	node.addEventListener ( event, handler, false );
}

function removeEventListener ( node, event, handler ) {
	node.removeEventListener ( event, handler, false );
}

function get ( key ) {
	return key ? this._state[ key ] : this._state;
}

function fire ( eventName, data ) {
	var handlers = eventName in this._handlers && this._handlers[ eventName ].slice();
	if ( !handlers ) return;

	for ( var i = 0; i < handlers.length; i += 1 ) {
		handlers[i].call( this, data );
	}
}

function observe ( key, callback, options ) {
	var group = ( options && options.defer ) ? this._observers.pre : this._observers.post;

	( group[ key ] || ( group[ key ] = [] ) ).push( callback );

	if ( !options || options.init !== false ) {
		callback.__calling = true;
		callback.call( this, this._state[ key ] );
		callback.__calling = false;
	}

	return {
		cancel: function () {
			var index = group[ key ].indexOf( callback );
			if ( ~index ) group[ key ].splice( index, 1 );
		}
	};
}

function on ( eventName, handler ) {
	if ( eventName === 'teardown' ) return this.on( 'destroy', handler );

	var handlers = this._handlers[ eventName ] || ( this._handlers[ eventName ] = [] );
	handlers.push( handler );

	return {
		cancel: function () {
			var index = handlers.indexOf( handler );
			if ( ~index ) handlers.splice( index, 1 );
		}
	};
}

function set ( newState ) {
	this._set( newState );
	( this._root || this )._flush();
}

function _flush () {
	if ( !this._renderHooks ) return;

	while ( this._renderHooks.length ) {
		var hook = this._renderHooks.pop();
		hook.fn.call( hook.context );
	}
}

var proto = {
	get: get,
	fire: fire,
	observe: observe,
	on: on,
	set: set,
	_flush: _flush
};

function noop () {}

function dispatchObservers ( component, group, newState, oldState ) {
	for ( var key in group ) {
		if ( !( key in newState ) ) continue;

		var newValue = newState[ key ];
		var oldValue = oldState[ key ];

		if ( newValue === oldValue && typeof newValue !== 'object' ) continue;

		var callbacks = group[ key ];
		if ( !callbacks ) continue;

		for ( var i = 0; i < callbacks.length; i += 1 ) {
			var callback = callbacks[i];
			if ( callback.__calling ) continue;

			callback.__calling = true;
			callback.call( component, newValue, oldValue );
			callback.__calling = false;
		}
	}
}

var template = (function () {
  return {
    data() {
      return {
        class: '',
        color: 'default',
        pill: false
      };
    }
  };
}());

function renderMainFragment ( root, component ) {
	var span = createElement( 'span' );
	span.className = "badge badge-" + ( root.color ) + ( root.pill ? ' badge-pill' : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, span );

	return {
		mount: function ( target, anchor ) {
			insertNode( span, target, anchor );
			component._yield && component._yield.mount( span, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			span.className = "badge badge-" + ( root.color ) + ( root.pill ? ' badge-pill' : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( span );
			}
		}
	};
}

function Badge ( options ) {
	options = options || {};
	this._state = Object.assign( template.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Badge.prototype = Object.assign( {}, proto );

Badge.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Badge.prototype.teardown = Badge.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$1 = (function () {
  return {
    methods: {
      onClick(e) {
        const { disabled } = this.get();
        if (disabled) {
          e.preventDefault();
          return;
        } else {
          this.fire('click', e);
        }
      }
    },
    data() {
      return {
        active: false,
        block: false,
        class: '',
        color: 'secondary',
        outline: false,
        size: null
      }
    }
  }
}());

function renderMainFragment$1 ( root, component ) {
	var Button = createElement( 'Button' );
	Button.className = "btn btn" + ( root.outline ? '-outline' : '' ) + "-" + ( root.color ) + ( root.size ? ` btn-${root.size}` : '' ) + ( root.block ? ' btn-block' : '' ) + ( root.active ? ' active' : '' ) + ( root.disabled ? ' disabled' : '' );
	
	function clickHandler ( event ) {
		component.onClick(event);
	}
	
	addEventListener( Button, 'click', clickHandler );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, Button );

	return {
		mount: function ( target, anchor ) {
			insertNode( Button, target, anchor );
			component._yield && component._yield.mount( Button, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			Button.className = "btn btn" + ( root.outline ? '-outline' : '' ) + "-" + ( root.color ) + ( root.size ? ` btn-${root.size}` : '' ) + ( root.block ? ' btn-block' : '' ) + ( root.active ? ' active' : '' ) + ( root.disabled ? ' disabled' : '' );
		},
		
		teardown: function ( detach ) {
			removeEventListener( Button, 'click', clickHandler );
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( Button );
			}
		}
	};
}

function Button ( options ) {
	options = options || {};
	this._state = Object.assign( template$1.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$1( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Button.prototype = Object.assign( {}, template$1.methods, proto );

Button.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Button.prototype.teardown = Button.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$2 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$2 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "" + ( root.size ? `btn-group-${root.size} ` : '' ) + ( root.vertical ? 'btn-group-vertical' : 'btn-group' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "" + ( root.size ? `btn-group-${root.size} ` : '' ) + ( root.vertical ? 'btn-group-vertical' : 'btn-group' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function ButtonGroup ( options ) {
	options = options || {};
	this._state = Object.assign( template$2.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$2( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

ButtonGroup.prototype = Object.assign( {}, proto );

ButtonGroup.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ButtonGroup.prototype.teardown = ButtonGroup.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$3 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function renderMainFragment$3 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "btn-toolbar " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "btn-toolbar " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function ButtonToolbar ( options ) {
	options = options || {};
	this._state = Object.assign( template$3.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$3( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

ButtonToolbar.prototype = Object.assign( {}, proto );

ButtonToolbar.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ButtonToolbar.prototype.teardown = ButtonToolbar.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

/**
 * lodash 3.0.2 (Custom Build) <https://lodash.com/>
 * Build: `lodash modern modularize exports="npm" -o ./`
 * Copyright 2012-2015 The Dojo Foundation <http://dojofoundation.org/>
 * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
 * Copyright 2009-2015 Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
 * Available under MIT license <https://lodash.com/license>
 */

/**
 * Checks if `value` is the [language type](https://es5.github.io/#x8) of `Object`.
 * (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
 *
 * @static
 * @memberOf _
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an object, else `false`.
 * @example
 *
 * _.isObject({});
 * // => true
 *
 * _.isObject([1, 2, 3]);
 * // => true
 *
 * _.isObject(1);
 * // => false
 */
function isObject(value) {
  // Avoid a V8 JIT bug in Chrome 19-20.
  // See https://code.google.com/p/v8/issues/detail?id=2291 for more details.
  var type = typeof value;
  return !!value && (type == 'object' || type == 'function');
}

var index = isObject;

function applyComputations ( state, newState, oldState, isInitial ) {
	if ( isInitial || ( 'widths' in newState && typeof state.widths === 'object' || state.widths !== oldState.widths ) || ( 'xs' in newState && typeof state.xs === 'object' || state.xs !== oldState.xs ) || ( 'sm' in newState && typeof state.sm === 'object' || state.sm !== oldState.sm ) || ( 'md' in newState && typeof state.md === 'object' || state.md !== oldState.md ) || ( 'lg' in newState && typeof state.lg === 'object' || state.lg !== oldState.lg ) || ( 'xl' in newState && typeof state.xl === 'object' || state.xl !== oldState.xl ) ) {
		state.classes = newState.classes = template$4.computed.classes( state.widths, state.xs, state.sm, state.md, state.lg, state.xl );
	}
}

var template$4 = (function () {
  const widths = ['xs', 'sm', 'md', 'lg', 'xl'];

  const getColumnSizeClass = (isXs, colWidth, colSize) => {
    if (colSize === true || colSize === '') {
      return isXs ? 'col' : `col-${colWidth}`;
    } else if (colSize === 'auto') {
      return isXs ? 'col-auto' : `col-${colWidth}-auto`;
    }

    return isXs ? `col-${colSize}` : `col-${colWidth}-${colSize}`;
  };

  return {
    data() {
      return {
        class: '',
        widths
      }
    },
    computed: {
      classes(widths, xs, sm, md, lg, xl) {
        const colClasses = [];
        const props = {
          xs,
          sm,
          md,
          lg,
          xl
        };

        widths.forEach((colWidth, i) => {
          let columnProp = props[colWidth];

          if (!i && columnProp === undefined) {
            columnProp = true;
          }

          if (!columnProp) {
            return;
          }

          const isXs = !i;
          let colClass;

          if (index(columnProp)) {
            const colSizeInterfix = isXs ? '-' : `-${colWidth}-`;
            colClass = getColumnSizeClass(isXs, colWidth, columnProp.size);

            colClasses.push(classNames({
              [colClass]: columnProp.size || columnProp.size === '', [`push${colSizeInterfix}${columnProp.push}`]: columnProp.push, [`pull${colSizeInterfix}${columnProp.pull}`]: columnProp.pull, [`offset${colSizeInterfix}${columnProp.offset}`]: columnProp.offset
            }));
          } else {
            colClass = getColumnSizeClass(isXs, colWidth, columnProp);
            colClasses.push(colClass);
          }
        });
        
        return colClasses.join(' ');
      }
    }
  }
}());

function renderMainFragment$4 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "" + ( root.classes ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "" + ( root.classes ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function Col ( options ) {
	options = options || {};
	this._state = Object.assign( template$4.data(), options.data );
	applyComputations( this._state, this._state, {}, true );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$4( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Col.prototype = Object.assign( {}, proto );

Col.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	applyComputations( this._state, newState, oldState, false );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Col.prototype.teardown = Col.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$5 = (function () {
  return {
    data() {
      return {
        class: '',
        fluid: false
      }
    }
  };
}());

function renderMainFragment$5 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "container" + ( root.fluid ? '-fluid' : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "container" + ( root.fluid ? '-fluid' : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function Container ( options ) {
	options = options || {};
	this._state = Object.assign( template$5.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$5( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Container.prototype = Object.assign( {}, proto );

Container.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Container.prototype.teardown = Container.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$6 = (function () {
  return {
    data() {
      return {
        border: false,
        class: '',
        fixedWidth: false,
        flip: false,
        inverse: false,
        pulse: false,
        rotate: false,
        size: false,
        spin: false,
        stack: false
      }
    }
  }
}());

function renderMainFragment$6 ( root, component ) {
	var i = createElement( 'i' );
	i.className = "fa fa-" + ( root.name ) + ( root.size ? ' fa-' + root.size : '' ) + ( root.spin ? ' fa-spin' : '' ) + ( root.pulse ? ' fa-pulse' : '' ) + ( root.border ? ' fa-border' : '' ) + ( root.fixedWidth ? ' fa-fw' : '' ) + ( root.inverse ? ' fa-inverse' : '' ) + ( root.flip ? ' fa-flip-' + root.flip : '' ) + ( root.rotate ? ' fa-rotate-' + root.rotate : '' ) + ( root.stack ? ' fa-stack-' + root.stack : '' ) + " " + ( root.class );

	return {
		mount: function ( target, anchor ) {
			insertNode( i, target, anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			i.className = "fa fa-" + ( root.name ) + ( root.size ? ' fa-' + root.size : '' ) + ( root.spin ? ' fa-spin' : '' ) + ( root.pulse ? ' fa-pulse' : '' ) + ( root.border ? ' fa-border' : '' ) + ( root.fixedWidth ? ' fa-fw' : '' ) + ( root.inverse ? ' fa-inverse' : '' ) + ( root.flip ? ' fa-flip-' + root.flip : '' ) + ( root.rotate ? ' fa-rotate-' + root.rotate : '' ) + ( root.stack ? ' fa-stack-' + root.stack : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			if ( detach ) {
				detachNode( i );
			}
		}
	};
}

function Icon ( options ) {
	options = options || {};
	this._state = Object.assign( template$6.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$6( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Icon.prototype = Object.assign( {}, proto );

Icon.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Icon.prototype.teardown = Icon.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$7 = (function () {
  return {
    data() {
      return {
        class: '',
        flush: false
      }
    }
  }
}());

function renderMainFragment$7 ( root, component ) {
	var ul = createElement( 'ul' );
	ul.className = "list-group" + ( root.flush ? ' list-group-flush' : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, ul );

	return {
		mount: function ( target, anchor ) {
			insertNode( ul, target, anchor );
			component._yield && component._yield.mount( ul, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			ul.className = "list-group" + ( root.flush ? ' list-group-flush' : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( ul );
			}
		}
	};
}

function ListGroup ( options ) {
	options = options || {};
	this._state = Object.assign( template$7.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$7( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

ListGroup.prototype = Object.assign( {}, proto );

ListGroup.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ListGroup.prototype.teardown = ListGroup.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$8 = (function () {
  return {
    data() {
      return {
        active: false,
        class: '',
        disabled: false,
        action: false,
        color: false
      }
    }
  }
}());

function renderMainFragment$8 ( root, component ) {
	var li = createElement( 'li' );
	li.className = "list-group-item" + ( root.active ? ' active' : '' ) + ( root.disabled ? ' disabled' : '' ) + ( root.action ? ' list-group-item-action' : '' ) + ( root.color ? ` list-group-item-${root.color}` : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, li );

	return {
		mount: function ( target, anchor ) {
			insertNode( li, target, anchor );
			component._yield && component._yield.mount( li, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			li.className = "list-group-item" + ( root.active ? ' active' : '' ) + ( root.disabled ? ' disabled' : '' ) + ( root.action ? ' list-group-item-action' : '' ) + ( root.color ? ` list-group-item-${root.color}` : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( li );
			}
		}
	};
}

function ListGroupItem ( options ) {
	options = options || {};
	this._state = Object.assign( template$8.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$8( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

ListGroupItem.prototype = Object.assign( {}, proto );

ListGroupItem.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ListGroupItem.prototype.teardown = ListGroupItem.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

/**
 * lodash (Custom Build) <https://lodash.com/>
 * Build: `lodash modularize exports="npm" -o ./`
 * Copyright jQuery Foundation and other contributors <https://jquery.org/>
 * Released under MIT license <https://lodash.com/license>
 * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
 * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
 */

/** Used as references for various `Number` constants. */
var NAN = 0 / 0;

/** `Object#toString` result references. */
var symbolTag = '[object Symbol]';

/** Used to match leading and trailing whitespace. */
var reTrim = /^\s+|\s+$/g;

/** Used to detect bad signed hexadecimal string values. */
var reIsBadHex = /^[-+]0x[0-9a-f]+$/i;

/** Used to detect binary string values. */
var reIsBinary = /^0b[01]+$/i;

/** Used to detect octal string values. */
var reIsOctal = /^0o[0-7]+$/i;

/** Built-in method references without a dependency on `root`. */
var freeParseInt = parseInt;

/** Used for built-in method references. */
var objectProto = Object.prototype;

/**
 * Used to resolve the
 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
 * of values.
 */
var objectToString = objectProto.toString;

/**
 * Checks if `value` is the
 * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)
 * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an object, else `false`.
 * @example
 *
 * _.isObject({});
 * // => true
 *
 * _.isObject([1, 2, 3]);
 * // => true
 *
 * _.isObject(_.noop);
 * // => true
 *
 * _.isObject(null);
 * // => false
 */
function isObject$1(value) {
  var type = typeof value;
  return !!value && (type == 'object' || type == 'function');
}

/**
 * Checks if `value` is object-like. A value is object-like if it's not `null`
 * and has a `typeof` result of "object".
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
 * @example
 *
 * _.isObjectLike({});
 * // => true
 *
 * _.isObjectLike([1, 2, 3]);
 * // => true
 *
 * _.isObjectLike(_.noop);
 * // => false
 *
 * _.isObjectLike(null);
 * // => false
 */
function isObjectLike(value) {
  return !!value && typeof value == 'object';
}

/**
 * Checks if `value` is classified as a `Symbol` primitive or object.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a symbol, else `false`.
 * @example
 *
 * _.isSymbol(Symbol.iterator);
 * // => true
 *
 * _.isSymbol('abc');
 * // => false
 */
function isSymbol(value) {
  return typeof value == 'symbol' ||
    (isObjectLike(value) && objectToString.call(value) == symbolTag);
}

/**
 * Converts `value` to a number.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to process.
 * @returns {number} Returns the number.
 * @example
 *
 * _.toNumber(3.2);
 * // => 3.2
 *
 * _.toNumber(Number.MIN_VALUE);
 * // => 5e-324
 *
 * _.toNumber(Infinity);
 * // => Infinity
 *
 * _.toNumber('3.2');
 * // => 3.2
 */
function toNumber(value) {
  if (typeof value == 'number') {
    return value;
  }
  if (isSymbol(value)) {
    return NAN;
  }
  if (isObject$1(value)) {
    var other = typeof value.valueOf == 'function' ? value.valueOf() : value;
    value = isObject$1(other) ? (other + '') : other;
  }
  if (typeof value != 'string') {
    return value === 0 ? value : +value;
  }
  value = value.replace(reTrim, '');
  var isBinary = reIsBinary.test(value);
  return (isBinary || reIsOctal.test(value))
    ? freeParseInt(value.slice(2), isBinary ? 2 : 8)
    : (reIsBadHex.test(value) ? NAN : +value);
}

var index$1 = toNumber;

function applyComputations$1 ( state, newState, oldState, isInitial ) {
	if ( isInitial || ( 'value' in newState && typeof state.value === 'object' || state.value !== oldState.value ) || ( 'max' in newState && typeof state.max === 'object' || state.max !== oldState.max ) ) {
		state.percent = newState.percent = template$9.computed.percent( state.value, state.max );
	}
}

var template$9 = (function () {
return {
  data() {
    return {
      bar: false,
      class: '',
      value: 0,
      max: 100,
      multi: false
    }
  },
  computed: {
    percent(value, max) {
      return (index$1(value) / index$1(max)) * 100;
    }
  }
}
}());

function renderMainFragment$9 ( root, component ) {
	var ifBlock_anchor = createComment();
	
	function getBlock ( root ) {
		if ( !root.bar ) return renderIfBlock_0;
		return renderIfBlock_1;
	}
	
	var currentBlock = getBlock( root );
	var ifBlock = currentBlock && currentBlock( root, component );

	return {
		mount: function ( target, anchor ) {
			insertNode( ifBlock_anchor, target, anchor );
			if ( ifBlock ) ifBlock.mount( ifBlock_anchor.parentNode, ifBlock_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			var _currentBlock = currentBlock;
			currentBlock = getBlock( root );
			if ( _currentBlock === currentBlock && ifBlock) {
				ifBlock.update( changed, root );
			} else {
				if ( ifBlock ) ifBlock.teardown( true );
				ifBlock = currentBlock && currentBlock( root, component );
				if ( ifBlock ) ifBlock.mount( ifBlock_anchor.parentNode, ifBlock_anchor );
			}
		},
		
		teardown: function ( detach ) {
			if ( ifBlock ) ifBlock.teardown( detach );
			
			if ( detach ) {
				detachNode( ifBlock_anchor );
			}
		}
	};
}

function renderIfBlock_1 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "progress-bar" + ( root.animated ? ' progress-bar-animated' : '' ) + ( root.color ? ` bg-${root.color}` : '' ) + ( root.striped || root.animated ? ' progress-bar-striped' : '' );
	div.style.cssText = "width:" + ( root.percent ) + "%";
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "progress-bar" + ( root.animated ? ' progress-bar-animated' : '' ) + ( root.color ? ` bg-${root.color}` : '' ) + ( root.striped || root.animated ? ' progress-bar-striped' : '' );
			div.style.cssText = "width:" + ( root.percent ) + "%";
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function renderIfBlock_0 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "progress " + ( root.class );
	
	var ifBlock1_anchor = createComment();
	appendNode( ifBlock1_anchor, div );
	
	function getBlock1 ( root ) {
		if ( root.multi ) return renderIfBlock1_0;
		return renderIfBlock1_1;
	}
	
	var currentBlock1 = getBlock1( root );
	var ifBlock1 = currentBlock1 && currentBlock1( root, component );
	
	if ( ifBlock1 ) ifBlock1.mount( ifBlock1_anchor.parentNode, ifBlock1_anchor );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "progress " + ( root.class );
			
			var _currentBlock1 = currentBlock1;
			currentBlock1 = getBlock1( root );
			if ( _currentBlock1 === currentBlock1 && ifBlock1) {
				ifBlock1.update( changed, root );
			} else {
				if ( ifBlock1 ) ifBlock1.teardown( true );
				ifBlock1 = currentBlock1 && currentBlock1( root, component );
				if ( ifBlock1 ) ifBlock1.mount( ifBlock1_anchor.parentNode, ifBlock1_anchor );
			}
		},
		
		teardown: function ( detach ) {
			if ( ifBlock1 ) ifBlock1.teardown( false );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function renderIfBlock1_1 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "progress-bar" + ( root.animated ? ' progress-bar-animated' : '' ) + ( root.color ? ` bg-${root.color}` : '' ) + ( root.striped || root.animated ? ' progress-bar-striped' : '' );
	div.style.cssText = "width:" + ( root.percent ) + "%";
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "progress-bar" + ( root.animated ? ' progress-bar-animated' : '' ) + ( root.color ? ` bg-${root.color}` : '' ) + ( root.striped || root.animated ? ' progress-bar-striped' : '' );
			div.style.cssText = "width:" + ( root.percent ) + "%";
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function renderIfBlock1_0 ( root, component ) {
	var yield_anchor = createComment();

	return {
		mount: function ( target, anchor ) {
			insertNode( yield_anchor, target, anchor );
			component._yield && component._yield.mount( target, yield_anchor );
		},
		
		update: noop,
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( yield_anchor );
			}
		}
	};
}

function Progress ( options ) {
	options = options || {};
	this._state = Object.assign( template$9.data(), options.data );
	applyComputations$1( this._state, this._state, {}, true );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$9( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Progress.prototype = Object.assign( {}, proto );

Progress.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	applyComputations$1( this._state, newState, oldState, false );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Progress.prototype.teardown = Progress.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$10 = (function () {
  return {
    data() {
      return {
        class: '',
        noGutters: false
      }
    }
  };
}());

function renderMainFragment$10 ( root, component ) {
	var div = createElement( 'div' );
	div.className = "row" + ( root.noGutters ? ' no-gutters' : '' ) + " " + ( root.class );
	
	var yield_anchor = createComment();
	appendNode( yield_anchor, div );

	return {
		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			component._yield && component._yield.mount( div, yield_anchor );
		},
		
		update: function ( changed, root ) {
			var __tmp;
		
			div.className = "row" + ( root.noGutters ? ' no-gutters' : '' ) + " " + ( root.class );
		},
		
		teardown: function ( detach ) {
			component._yield && component._yield.teardown( detach );
			
			if ( detach ) {
				detachNode( div );
			}
		}
	};
}

function Row ( options ) {
	options = options || {};
	this._state = Object.assign( template$10.data(), options.data );
	
	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};
	
	this._handlers = Object.create( null );
	
	this._root = options._root;
	this._yield = options._yield;
	
	this._torndown = false;
	
	this._fragment = renderMainFragment$10( this._state, this );
	if ( options.target ) this._fragment.mount( options.target, null );
}

Row.prototype = Object.assign( {}, proto );

Row.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = Object.assign( {}, oldState, newState );
	
	dispatchObservers( this, this._observers.pre, newState, oldState );
	if ( this._fragment ) this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Row.prototype.teardown = Row.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	this._fragment.teardown( detach !== false );
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

exports.Badge = Badge;
exports.Button = Button;
exports.ButtonGroup = ButtonGroup;
exports.ButtonToolbar = ButtonToolbar;
exports.Col = Col;
exports.Container = Container;
exports.Icon = Icon;
exports.ListGroup = ListGroup;
exports.ListGroupItem = ListGroupItem;
exports.Progress = Progress;
exports.Row = Row;
